@@ -19,6 +19,7 @@
 #include <KLocalizedString>
 #include <KMime/Content>
 #include <KMime/Headers>
+#include <Libkleo/Formatting>
 
 #include <QByteArray>
 
@@ -89,7 +90,7 @@ void AutocryptHeadersJobPrivate::emitGpgError(const GpgME::Error &error)
         "<p>An error occurred while trying to export "
         "the key from the backend:</p>"
         "<p><b>%1</b></p>",
-        QString::fromLocal8Bit(error.asString()));
+        Kleo::Formatting::errorAsString(error));
     q->setError(KJob::UserDefinedError);
     q->setErrorText(msg);
     q->emitResult();
