@@ -4,8 +4,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_AUTOCRYPTHEADERSJOB_H
-#define MESSAGECOMPOSER_AUTOCRYPTHEADERSJOB_H
+#pragma once
 
 #include "contentjobbase.h"
 #include "messagecomposer_export.h"
@@ -49,5 +48,3 @@ private:
     Q_DECLARE_PRIVATE(AutocryptHeadersJob)
 };
 }
-
-#endif
