@@ -5,16 +5,15 @@
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef MESSAGECOMPOSER_RECIPIENTSPICKER_H
-#define MESSAGECOMPOSER_RECIPIENTSPICKER_H
+#pragma once
 
 #include <MessageComposer/Recipient>
 
+#include <KContacts/Addressee>
 #include <QDialog>
-#include <kcontacts/addressee.h>
 
 class QPushButton;
-
+class QLabel;
 namespace PimCommon
 {
 class LdapSearchDialog;
@@ -61,16 +60,16 @@ protected Q_SLOTS:
     void slotSelectionChanged();
 
 private:
-    Akonadi::RecipientsPickerWidget *mView = nullptr;
+    void updateLabel(int nbSelected);
+    Akonadi::RecipientsPickerWidget *const mView;
 
     PimCommon::LdapSearchDialog *mLdapSearchDialog = nullptr;
 
     Recipient::Type mDefaultType;
-    QPushButton *mUser4Button = nullptr;
-    QPushButton *mUser3Button = nullptr;
-    QPushButton *mUser2Button = nullptr;
-    QPushButton *mUser1Button = nullptr;
+    QPushButton *const mUser1Button;
+    QPushButton *const mUser2Button;
+    QPushButton *const mUser3Button;
+    QPushButton *const mUser4Button;
+    QLabel *const mSelectedLabel;
 };
 }
-
-#endif
