@@ -2,10 +2,11 @@
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef AUTOCRYPTSTORAGETEST_H
-#define AUTOCRYPTSTORAGETEST_H
+#pragma once
 
 #include <QDir>
+using namespace Qt::Literals::StringLiterals;
+
 #include <QObject>
 
 class AutocryptStorageTest : public QObject
@@ -27,5 +28,3 @@ private Q_SLOTS:
 private:
     QDir baseDir;
 };
-
-#endif
