@@ -7,8 +7,6 @@
  *******************************************************************************/
 
 #include "core/delegate.h"
-#include "core/groupheaderitem.h"
-#include "core/messageitem.h"
 #include "core/view.h"
 
 using namespace MessageList::Core;
@@ -18,11 +16,11 @@ Delegate::Delegate(View *pParent)
 {
 }
 
-Delegate::~Delegate()
-{
-}
+Delegate::~Delegate() = default;
 
 Item *Delegate::itemFromIndex(const QModelIndex &index) const
 {
     return static_cast<Item *>(index.internalPointer());
 }
+
+#include "moc_delegate.cpp"
