@@ -6,8 +6,7 @@
  *
  *******************************************************************************/
 
-#ifndef MESSAGELIST_CORE_ENUMS_H
-#define MESSAGELIST_CORE_ENUMS_H
+#pragma once
 
 namespace MessageList
 {
@@ -31,7 +30,7 @@ enum PreSelectionMode {
     PreSelectLastSelected, //< pre-select the last message that was selected in this folder (default)
     PreSelectFirstUnreadCentered, //< pre-select the first unread message and center it
     PreSelectNewestCentered, //< pre-select the newest message, by date
-    PreSelectOldestCentered //< pre-select the oldest message, by date
+    PreSelectOldestCentered, //< pre-select the oldest message, by date
 };
 
 /**
@@ -39,7 +38,7 @@ enum PreSelectionMode {
  */
 enum MessageTypeFilter {
     MessageTypeAny, //< Select any message
-    MessageTypeUnreadOnly //< Select only unread messages
+    MessageTypeUnreadOnly, //< Select only unread messages
 };
 
 /**
@@ -52,5 +51,3 @@ enum ExistingSelectionBehaviour {
 };
 }
 }
-
-#endif //!__MESSAGELIST_CORE_ENUMS_H
