@@ -6,8 +6,7 @@
  *
  *******************************************************************************/
 
-#ifndef MESSAGELIST_CORE_GROUPHEADERITEM_H
-#define MESSAGELIST_CORE_GROUPHEADERITEM_H
+#pragma once
 
 #include <QString>
 
@@ -23,7 +22,7 @@ public:
     explicit GroupHeaderItem(const QString &label);
     ~GroupHeaderItem() override;
 
-    Q_REQUIRED_RESULT const QString &label() const;
+    [[nodiscard]] const QString &label() const;
     void setLabel(const QString &label);
 
 private:
@@ -31,5 +30,3 @@ private:
 };
 } // namespace Core
 } // namespace MessageList
-
-#endif //!__MESSAGELIST_CORE_GROUPHEADERITEM_H
