@@ -89,6 +89,11 @@ public:
     void addMessageToSubjectBasedThreadingCache(MessageItem *mi);
     void removeMessageFromSubjectBasedThreadingCache(MessageItem *mi);
     void clear();
+    /**
+     * Expand the view while temporarily disabling animations - for expansion *not* triggered by the user
+     * clicking on expand, which is often a mass operation, and animations are expensive.
+     */
+    void expandViewNoninteractive(const QModelIndex &index);
     /**
      * Sync the expanded state of the subtree with the specified root.
      * This will cause the items that are marked with Item::ExpandNeeded to be
@@ -369,7 +374,7 @@ public:
     /**
      * We need to save the current item before each job step. This is because
      * our job may cause items to be reparented (thus removed and read with the current Qt API)
-     * and QTreeView will loose the current setting. We also use this to force the current
+     * and QTreeView will lose the current setting. We also use this to force the current
      * to a specific item after a cleanup job.
      */
     Item *mCurrentItemToRestoreAfterViewItemJobStep = nullptr;
