@@ -192,11 +192,6 @@ public:
              * The list of MessageItem::Tag entries
              */
             TagList = 22 | ApplicableToMessageItems | IsIcon,
-            /**
-             * Whether the message has a annotation/note
-             */
-            AnnotationIcon = 23 | ApplicableToMessageItems | IsIcon | CanBeDisabled | IsClickable,
-
             /**
              * Whether the message is an invitation
              */
