@@ -124,7 +124,7 @@ Widget::Widget(QWidget *pParent)
     g->setContentsMargins({});
     g->setSpacing(0);
 
-    d->quickSearchLine = new QuickSearchLine;
+    d->quickSearchLine = new QuickSearchLine(this);
     d->quickSearchLine->setObjectName(QLatin1StringView("quicksearchline"));
     connect(d->quickSearchLine, &QuickSearchLine::clearButtonClicked, this, &Widget::searchEditClearButtonClicked);
 
@@ -284,15 +284,6 @@ QString Widget::currentFilterSearchString() const
     return {};
 }
 
-QString Widget::currentFilterTagId() const
-{
-    if (d->mFilter) {
-        return d->mFilter->tagId();
-    }
-
-    return {};
-}
-
 void Widget::WidgetPrivate::setDefaultAggregationForStorageModel(const StorageModel *storageModel)
 {
     const Aggregation *opt = Manager::instance()->aggregationForStorageModel(storageModel, &mStorageUsesPrivateAggregation);
@@ -361,14 +352,16 @@ void Widget::saveCurrentSelection()
 void Widget::setStorageModel(StorageModel *storageModel, PreSelectionMode preSelectionMode)
 {
     if (storageModel == d->mStorageModel) {
-        return; // nuthin to do here
+        return; // nothing to do here
     }
 
     d->setDefaultAggregationForStorageModel(storageModel);
     d->setDefaultThemeForStorageModel(storageModel);
     d->setDefaultSortOrderForStorageModel(storageModel);
 
-    if (!d->quickSearchLine->searchEdit()->locked()) {
+    const bool isLocked = d->quickSearchLine->searchEdit()->locked();
+    // qDebug() << " isLocked " << isLocked;
+    if (!isLocked) {
         if (d->mSearchTimer) {
             d->mSearchTimer->stop();
             delete d->mSearchTimer;
@@ -935,7 +928,7 @@ void Widget::tagIdSelected(const QVariant &data)
         if (!d->mFilter) {
             d->mFilter = new Filter();
         }
-        d->mFilter->setTagId(tagId);
+        d->mFilter->setTagId({tagId});
     }
 
     d->mView->model()->setFilter(d->mFilter);
@@ -989,7 +982,7 @@ void Widget::slotStatusButtonsClicked()
     // We also arbitrarily set tagId to an empty string, though we *could* allow filtering
     // by status AND tag...
     if (d->mFilter) {
-        d->mFilter->setTagId(QString());
+        d->mFilter->setTagId(QStringList());
     }
 
     auto lst = d->quickSearchLine->status();
