@@ -5,6 +5,7 @@
 */
 
 #include "searchlinestatus.h"
+#include "searchlinecommand.h"
 
 #include "configurefiltersdialog.h"
 #include "core/filtersavedmanager.h"
@@ -24,6 +25,7 @@
 #include <QStandardPaths>
 #include <QStringListModel>
 #include <QWidgetAction>
+using namespace Qt::Literals::StringLiterals;
 
 static const char qLineEditclearButtonActionNameC[] = "_q_qlineeditclearaction";
 #define MAX_COMPLETION_ITEMS 20
@@ -47,6 +49,7 @@ SearchLineStatus::SearchLineStatus(QWidget *parent)
         qCWarning(MESSAGELIST_LOG) << "Clear button name was changed ! Please verify qt code";
     }
     connect(FilterSavedManager::self(), &FilterSavedManager::activateFilter, this, &SearchLineStatus::slotActivateFilter);
+    loadSearchLineCommand();
 }
 
 SearchLineStatus::~SearchLineStatus() = default;
@@ -74,10 +77,10 @@ void SearchLineStatus::slotClear()
 void SearchLineStatus::updateLockAction()
 {
     if (mLocked) {
-        mLockAction->setIcon(QIcon::fromTheme(QStringLiteral("object-locked")));
+        mLockAction->setIcon(QIcon::fromTheme(u"object-locked"_s));
         mLockAction->setToolTip(i18nc("@info:tooltip", "Prevent the quick search field from being cleared when changing folders"));
     } else {
-        mLockAction->setIcon(QIcon::fromTheme(QStringLiteral("object-unlocked")));
+        mLockAction->setIcon(QIcon::fromTheme(u"object-unlocked"_s));
         mLockAction->setToolTip(i18nc("@info:tooltip", "Clear the quick search field when changing folders"));
     }
 }
@@ -96,10 +99,10 @@ bool SearchLineStatus::locked() const
 
 void SearchLineStatus::initializeActions()
 {
-    mSearchCommandAction = addAction(QIcon::fromTheme(QStringLiteral("settings-configure")), QLineEdit::TrailingPosition);
+    mSearchCommandAction = addAction(QIcon::fromTheme(u"settings-configure"_s), QLineEdit::TrailingPosition);
     mSearchCommandAction->setWhatsThis(i18nc("@info:whatsthis", "Toggle this button if you want show or hide search command line widget."));
     connect(mSearchCommandAction, &QAction::triggered, this, &SearchLineStatus::searchCommandActionRequested);
-    mLockAction = addAction(QIcon::fromTheme(QStringLiteral("object-locked")), QLineEdit::TrailingPosition);
+    mLockAction = addAction(QIcon::fromTheme(u"object-locked"_s), QLineEdit::TrailingPosition);
     mLockAction->setWhatsThis(i18nc("@info:whatsthis",
                                     "Toggle this button if you want to keep your quick search "
                                     "locked when moving to other folders or when narrowing the search "
@@ -108,7 +111,7 @@ void SearchLineStatus::initializeActions()
     connect(mLockAction, &QAction::triggered, this, &SearchLineStatus::slotToggledLockAction);
     updateLockAction();
 
-    mSaveFilterAction = addAction(QIcon::fromTheme(QStringLiteral("edit-find")), QLineEdit::LeadingPosition);
+    mSaveFilterAction = addAction(QIcon::fromTheme(u"edit-find"_s), QLineEdit::LeadingPosition);
     mSaveFilterAction->setToolTip(i18nc("@info:tooltip", "Saved Filter"));
     mFilterSavedMenu = new FilterSavedMenu(this);
     mSaveFilterAction->setMenu(mFilterSavedMenu);
@@ -157,7 +160,7 @@ void SearchLineStatus::updateFilterLineEditBackgroundColor()
         KStatefulBrush bgBrush(KColorScheme::View, bgColorScheme);
         mColorName = bgBrush.brush(palette()).color().name();
     }
-    setStyleSheet(mHasFilter ? QStringLiteral("QLineEdit{ background-color:%1 }").arg(mColorName) : QString());
+    setStyleSheet(mHasFilter ? u"QLineEdit{ background-color:%1 }"_s.arg(mColorName) : QString());
 }
 
 void SearchLineStatus::clearFilterButtonClicked()
@@ -179,7 +182,7 @@ void SearchLineStatus::addCompletionItem(const QString &str)
     while (mListCompetion.size() > MAX_COMPLETION_ITEMS) {
         mListCompetion.removeLast();
     }
-    mCompleterListModel->setStringList(mListCompetion);
+    mCompleterListModel->setStringList(mListCompetion + mCommandLineListCompletion);
 }
 
 void SearchLineStatus::contextMenuEvent(QContextMenuEvent *e)
@@ -187,7 +190,7 @@ void SearchLineStatus::contextMenuEvent(QContextMenuEvent *e)
     QMenu *popup = QLineEdit::createStandardContextMenu();
     if (popup) {
         popup->addSeparator();
-        popup->addAction(QIcon::fromTheme(QStringLiteral("edit-clear-locationbar-rtl")), i18n("Clear History"), this, &SearchLineStatus::slotClearHistory);
+        popup->addAction(QIcon::fromTheme(u"edit-clear-locationbar-rtl"_s), i18n("Clear History"), this, &SearchLineStatus::slotClearHistory);
         popup->exec(e->globalPos());
         delete popup;
     }
@@ -196,15 +199,22 @@ void SearchLineStatus::contextMenuEvent(QContextMenuEvent *e)
 void SearchLineStatus::slotClearHistory()
 {
     mListCompetion.clear();
-    mCompleterListModel->setStringList(mListCompetion);
+    mCompleterListModel->setStringList(mCommandLineListCompletion);
 }
 
 void SearchLineStatus::slotInsertCommand(const QString &command)
 {
-    if (!text().isEmpty() && text().back() != QLatin1Char(' ')) {
-        insert(QStringLiteral(" "));
+    if (!text().isEmpty() && text().back() != u' ') {
+        insert(u" "_s);
     }
     insert(command);
 }
 
+void SearchLineStatus::loadSearchLineCommand()
+{
+    for (int i = SearchLineCommand::SearchLineType::To; i <= SearchLineCommand::SearchLineType::Category; ++i) {
+        mCommandLineListCompletion.append(SearchLineCommand::generateCommandText(static_cast<SearchLineCommand::SearchLineType>(i)));
+    }
+}
+
 #include "moc_searchlinestatus.cpp"
