@@ -6,7 +6,6 @@
 
 #include "core/manager.h"
 #include "utils/aggregationcombobox.h"
-#include "utils/aggregationcombobox_p.h"
 #include "utils/configureaggregationsdialog.h"
 
 #include <KLocalizedString>
@@ -30,7 +29,7 @@ public:
 };
 
 AggregationConfigButton::AggregationConfigButton(QWidget *parent, const AggregationComboBox *aggregationComboBox)
-    : QPushButton(i18n("Configure..."), parent)
+    : QPushButton(i18nc("@action:button", "Configure..."), parent)
     , d(new AggregationConfigButtonPrivate(this))
 {
     d->mAggregationComboBox = aggregationComboBox;
@@ -39,16 +38,13 @@ AggregationConfigButton::AggregationConfigButton(QWidget *parent, const Aggregat
     });
 
     // Keep aggregation combo up-to-date with any changes made in the configure dialog.
-    if (d->mAggregationComboBox != nullptr) {
+    if (d->mAggregationComboBox) {
         connect(this, &AggregationConfigButton::configureDialogCompleted, d->mAggregationComboBox, &AggregationComboBox::slotLoadAggregations);
     }
     setEnabled(Manager::instance());
 }
 
-AggregationConfigButton::~AggregationConfigButton()
-{
-    delete d;
-}
+AggregationConfigButton::~AggregationConfigButton() = default;
 
 void AggregationConfigButtonPrivate::slotConfigureAggregations()
 {
@@ -59,10 +55,9 @@ void AggregationConfigButtonPrivate::slotConfigureAggregations()
 
     auto dialog = new ConfigureAggregationsDialog(q->window());
     dialog->selectAggregation(currentAggregationID);
-
-    QObject::connect(dialog, &ConfigureAggregationsDialog::okClicked, q, &AggregationConfigButton::configureDialogCompleted);
-
-    dialog->show();
+    if (dialog->exec()) {
+        Q_EMIT q->configureDialogCompleted();
+    }
 }
 
 #include "moc_aggregationconfigbutton.cpp"
