@@ -48,9 +48,7 @@ OptionSetEditor::OptionSetEditor(QWidget *parent)
     tabg->setRowStretch(2, 1);
 }
 
-OptionSetEditor::~OptionSetEditor()
-{
-}
+OptionSetEditor::~OptionSetEditor() = default;
 
 void OptionSetEditor::setReadOnly(bool readOnly)
 {
@@ -67,3 +65,5 @@ QLineEdit *OptionSetEditor::nameEdit() const
 {
     return mNameEdit;
 }
+
+#include "moc_optionseteditor.cpp"
