@@ -33,12 +33,14 @@
 #include <QUrl>
 
 #include "core/groupheaderitem.h"
+#include "tagmanager.h"
 
 #include <Akonadi/Monitor>
 #include <Akonadi/Tag>
 #include <Akonadi/TagAttribute>
 #include <Akonadi/TagFetchJob>
 #include <Akonadi/TagFetchScope>
+using namespace Qt::Literals::StringLiterals;
 
 namespace MessageList
 {
@@ -59,7 +61,6 @@ public:
     int mLastSelectedMessage = -1;
     KXMLGUIClient *mXmlGuiClient = nullptr;
     QModelIndex mGroupHeaderItemIndex;
-    Akonadi::Monitor *mMonitor = nullptr;
 };
 } // namespace MessageList
 
@@ -70,14 +71,9 @@ MessageList::Widget::Widget(QWidget *parent)
     : Core::Widget(parent)
     , d(new WidgetPrivate(this))
 {
-    populateStatusFilterCombo();
-
-    d->mMonitor = new Akonadi::Monitor(this);
-    d->mMonitor->setObjectName(QLatin1StringView("MessageListTagMonitor"));
-    d->mMonitor->setTypeMonitored(Akonadi::Monitor::Tags);
-    connect(d->mMonitor, &Akonadi::Monitor::tagAdded, this, &Widget::populateStatusFilterCombo);
-    connect(d->mMonitor, &Akonadi::Monitor::tagRemoved, this, &Widget::populateStatusFilterCombo);
-    connect(d->mMonitor, &Akonadi::Monitor::tagChanged, this, &Widget::populateStatusFilterCombo);
+    // Init it.
+    (void)Core::TagManager::self();
+    connect(Core::TagManager::self(), &Core::TagManager::tagsFetched, this, &MessageList::Widget::slotTagsFetched);
 }
 
 MessageList::Widget::~Widget() = default;
@@ -111,7 +107,7 @@ bool MessageList::Widget::canAcceptDrag(const QDropEvent *e)
             return false;
         } else { // Yay, this is an item!
             QUrlQuery query(url);
-            const QString type = query.queryItemValue(QStringLiteral("type"));
+            const QString type = query.queryItemValue(u"type"_s);
             if (!target.contentMimeTypes().contains(type)) {
                 return false;
             }
@@ -193,49 +189,32 @@ void MessageList::Widget::setQuickSearchClickMessage(const QString &msg)
     view()->setQuickSearchClickMessage(msg);
 }
 
-void MessageList::Widget::fillMessageTagCombo()
+void MessageList::Widget::slotTagsFetched(const Akonadi::Tag::List &tags)
 {
-    auto fetchJob = new Akonadi::TagFetchJob(this);
-    fetchJob->fetchScope().fetchAttribute<Akonadi::TagAttribute>();
-    connect(fetchJob, &Akonadi::TagFetchJob::result, this, &Widget::slotTagsFetched);
-}
-
-void MessageList::Widget::slotTagsFetched(KJob *job)
-{
-    if (job->error()) {
-        qCWarning(MESSAGELIST_LOG) << "Failed to load tags " << job->errorString();
-        return;
-    }
-    auto fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
-
-    KConfigGroup conf(MessageList::MessageListSettings::self()->config(), QStringLiteral("MessageListView"));
-    const QString tagSelected = conf.readEntry(QStringLiteral("TagSelected"));
+    populateStatusFilterCombo();
+    KConfigGroup conf(MessageList::MessageListSettings::self()->config(), u"MessageListView"_s);
+    const QString tagSelected = conf.readEntry(u"TagSelected"_s);
     if (tagSelected.isEmpty()) {
         setCurrentStatusFilterItem();
         return;
     }
-    const QStringList tagSelectedLst = tagSelected.split(QLatin1Char(','));
+    const QStringList tagSelectedLst = tagSelected.split(u',');
 
-    addMessageTagItem(QIcon::fromTheme(QStringLiteral("mail-flag")).pixmap(16, 16),
-                      i18nc("Item in list of Akonadi tags, to show all e-mails", "All"),
-                      QString());
+    addMessageTagItem(QIcon::fromTheme(u"mail-flag"_s).pixmap(16, 16), i18nc("Item in list of Akonadi tags, to show all e-mails", "All"), QVariant());
 
     QStringList tagFound;
-    const auto tags{fetchJob->tags()};
     for (const Akonadi::Tag &akonadiTag : tags) {
-        if (tagSelectedLst.contains(akonadiTag.url().url())) {
+        const QString tagUrl = akonadiTag.url().url();
+        if (tagSelectedLst.contains(tagUrl)) {
             tagFound.append(akonadiTag.url().url());
-            QString iconName = QStringLiteral("mail-tagged");
             const QString label = akonadiTag.name();
-            const QString id = akonadiTag.url().url();
+            const QString id = tagUrl;
             const auto attr = akonadiTag.attribute<Akonadi::TagAttribute>();
-            if (attr) {
-                iconName = attr->iconName();
-            }
+            const QString iconName = attr ? attr->iconName() : u"mail-tagged"_s;
             addMessageTagItem(QIcon::fromTheme(iconName).pixmap(16, 16), label, QVariant(id));
         }
     }
-    conf.writeEntry(QStringLiteral("TagSelected"), tagFound);
+    conf.writeEntry(u"TagSelected"_s, tagFound);
     conf.sync();
 
     setCurrentStatusFilterItem();
@@ -306,7 +285,7 @@ void MessageList::Widget::viewMessageListContextPopupRequest(const QList<Message
         return;
     }
 
-    QMenu *popup = static_cast<QMenu *>(d->mXmlGuiClient->factory()->container(QStringLiteral("akonadi_messagelist_contextmenu"), d->mXmlGuiClient));
+    QMenu *popup = static_cast<QMenu *>(d->mXmlGuiClient->factory()->container(u"akonadi_messagelist_contextmenu"_s, d->mXmlGuiClient));
     if (popup) {
         popup->exec(globalPos);
     }
@@ -419,11 +398,10 @@ void MessageList::Widget::viewDropEvent(QDropEvent *e)
             action = DragMove;
         } else {
             QMenu menu;
-            QAction *moveAction =
-                menu.addAction(QIcon::fromTheme(QStringLiteral("edit-move"), QIcon::fromTheme(QStringLiteral("go-jump"))), i18n("&Move Here"));
-            QAction *copyAction = menu.addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("&Copy Here"));
+            QAction *moveAction = menu.addAction(QIcon::fromTheme(u"edit-move"_s, QIcon::fromTheme(QStringLiteral("go-jump"))), i18n("&Move Here"));
+            QAction *copyAction = menu.addAction(QIcon::fromTheme(u"edit-copy"_s), i18n("&Copy Here"));
             menu.addSeparator();
-            menu.addAction(QIcon::fromTheme(QStringLiteral("dialog-cancel")), i18n("C&ancel"));
+            menu.addAction(QIcon::fromTheme(u"dialog-cancel"_s), i18n("C&ancel"));
 
             QAction *menuChoice = menu.exec(QCursor::pos());
             if (menuChoice == moveAction) {
@@ -484,7 +462,7 @@ void MessageList::Widget::viewStartDragRequest()
         const Akonadi::Item i = d->itemForRow(mi->currentModelIndexRow());
         QUrl url = i.url(Akonadi::Item::UrlWithMimeType);
         QUrlQuery query(url);
-        query.addQueryItem(QStringLiteral("parent"), QString::number(mi->parentCollectionId()));
+        query.addQueryItem(u"parent"_s, QString::number(mi->parentCollectionId()));
         url.setQuery(query);
         urls << url;
     }
@@ -498,9 +476,9 @@ void MessageList::Widget::viewStartDragRequest()
     // Set pixmap
     QPixmap pixmap;
     if (selection.size() == 1) {
-        pixmap = QIcon::fromTheme(QStringLiteral("mail-message")).pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize));
+        pixmap = QIcon::fromTheme(u"mail-message"_s).pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize));
     } else {
-        pixmap = QIcon::fromTheme(QStringLiteral("document-multiple")).pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize));
+        pixmap = QIcon::fromTheme(u"document-multiple"_s).pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize));
     }
 
     // Calculate hotspot (as in Konqueror)
