@@ -314,11 +314,6 @@ public:
     [[nodiscard]] QList<MessageList::Core::SearchLineCommand::SearchLineInfo> searchLineCommands() const;
 
 protected:
-    /**
-     * Reimplemented from MessageList::Core::Widget
-     */
-    void fillMessageTagCombo() override;
-
     /**
      * Reimplemented from MessageList::Core::Widget
      */
@@ -372,7 +367,7 @@ protected:
 private:
     MESSAGELIST_NO_EXPORT void slotCollapseItem();
     MESSAGELIST_NO_EXPORT void slotExpandItem();
-    MESSAGELIST_NO_EXPORT void slotTagsFetched(KJob *job);
+    MESSAGELIST_NO_EXPORT void slotTagsFetched(const Akonadi::Tag::List &tags);
 
 Q_SIGNALS:
     /**
