@@ -5,6 +5,8 @@
 */
 
 #include "dkimmanagerkeytreeview.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "dkimmanagerkeymodel.h"
 #include "dkimmanagerkeyproxymodel.h"
 #include <KLocalizedString>
@@ -68,26 +70,22 @@ void DKIMManagerKeyTreeView::slotCustomContextMenuRequested(const QPoint &pos)
 
     if (index.isValid()) {
         if (selectedItemCount == 1) {
-            menu.addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy Key"), this, [index, this]() {
+            menu.addAction(QIcon::fromTheme(u"edit-copy"_s), i18n("Copy Key"), this, [index, this]() {
                 QApplication::clipboard()->setText(mManagerKeyModel->index(index.row()).data(DKIMManagerKeyModel::KeyRole).toString());
             });
             menu.addSeparator();
         }
 
-        menu.addAction(QIcon::fromTheme(QStringLiteral("edit-delete")),
-                       i18np("Remove Key", "Remove Keys", selectedItemCount),
-                       this,
-                       [this, selectedItemCount]() {
-                           const int answer =
-                               KMessageBox::questionTwoActions(this,
+        menu.addAction(QIcon::fromTheme(u"edit-delete"_s), i18np("Remove Key", "Remove Keys", selectedItemCount), this, [this, selectedItemCount]() {
+            const int answer = KMessageBox::questionTwoActions(this,
                                                                i18np("Do you want to delete this key?", "Do you want to delete these keys?", selectedItemCount),
                                                                i18np("Delete Key", "Delete Keys", selectedItemCount),
                                                                KStandardGuiItem::del(),
                                                                KStandardGuiItem::cancel());
-                           if (answer == KMessageBox::ButtonCode::PrimaryAction) {
-                               deleteSelectedItems();
-                           }
-                       });
+            if (answer == KMessageBox::ButtonCode::PrimaryAction) {
+                deleteSelectedItems();
+            }
+        });
         menu.addSeparator();
     }
     if (mManagerKeyProxyModel->rowCount() > 0) {
