@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -20,7 +20,7 @@ class DKIMManageRulesComboBox;
 class MESSAGEVIEWER_EXPORT DKIMManageRulesWidgetItem : public QTreeWidgetItem
 {
 public:
-    enum ColumnType {
+    enum ColumnType : uint8_t {
         Enabled = 0,
         Domain = 1,
         ListId = 2,
