@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -18,7 +18,7 @@ class MESSAGEVIEWER_EXPORT DKIMRule
 {
     Q_GADGET
 public:
-    enum class RuleType {
+    enum class RuleType : uint8_t {
         Unknown = 0,
         MustBeSigned = 1,
         CanBeSigned = 2,
