@@ -5,6 +5,8 @@
 */
 
 #include "scamdetectionwebenginetest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "../scamdetectionwebengine.h"
 #include <QHBoxLayout>
 #include <QSignalSpy>
@@ -48,24 +50,23 @@ void ScamDetectionWebEngineTest::scamtest_data()
     QTest::addColumn<bool>("result");
 
     // No Scam
-    QTest::newRow("noscam1") << QStringLiteral("<html><body><a href=\"www.kde.org\">kde</a></body></html>") << false;
-    QTest::newRow("noscam2") << QStringLiteral("<html><body><a href=\"http://www.kde.org\" title=\"http://www.kde.org\">kde</a></body></html>") << false;
-    QTest::newRow("noscam3") << QStringLiteral("<html><body><a href=\"https://www.kde.org\" title=\"https://www.kde.org\">kde</a></body></html>") << false;
+    QTest::newRow("noscam1") << u"<html><body><a href=\"www.kde.org\">kde</a></body></html>"_s << false;
+    QTest::newRow("noscam2") << u"<html><body><a href=\"http://www.kde.org\" title=\"http://www.kde.org\">kde</a></body></html>"_s << false;
+    QTest::newRow("noscam3") << u"<html><body><a href=\"https://www.kde.org\" title=\"https://www.kde.org\">kde</a></body></html>"_s << false;
 
     // Hexa value
-    QTest::newRow("hexavalue") << QStringLiteral("<html><body><a href=\"http://125.15.55.88/\" title=\"http://0x12.0x1e.0x0A.0x00\">test</a></body></html>")
-                               << true;
+    QTest::newRow("hexavalue") << u"<html><body><a href=\"http://125.15.55.88/\" title=\"http://0x12.0x1e.0x0A.0x00\">test</a></body></html>"_s << true;
 
     // Ip
-    QTest::newRow("Ip value") << QStringLiteral("<html><body><a href=\"http://127.0.0.1/\">test</a></body></html>") << false;
-    QTest::newRow("Ip scam1") << QStringLiteral("<html><body><a href=\"http://125.15.55.88/\" title=\"http://www.kde.org\">test</a></body></html>") << true;
-    QTest::newRow("Ip scam2") << QStringLiteral("<html><body><a href=\"http://125.15.55.88/\" title=\"http://125.15.55.88/\">test</a></body></html>") << true;
+    QTest::newRow("Ip value") << u"<html><body><a href=\"http://127.0.0.1/\">test</a></body></html>"_s << false;
+    QTest::newRow("Ip scam1") << u"<html><body><a href=\"http://125.15.55.88/\" title=\"http://www.kde.org\">test</a></body></html>"_s << true;
+    QTest::newRow("Ip scam2") << u"<html><body><a href=\"http://125.15.55.88/\" title=\"http://125.15.55.88/\">test</a></body></html>"_s << true;
 
     // Href no scam
-    QTest::newRow("Href no scam") << QStringLiteral("<html><body><a href=\"http://www.kde.org/\" title=\"http://www.kde.org\">test</a></body></html>") << false;
+    QTest::newRow("Href no scam") << u"<html><body><a href=\"http://www.kde.org/\" title=\"http://www.kde.org\">test</a></body></html>"_s << false;
 
     // Redirect href
-    QTest::newRow("Redirect scam") << QStringLiteral("<html><body><a href=\"http://www.google.fr/url?q=http://www.yahoo.com\">test</a></body></html>") << true;
+    QTest::newRow("Redirect scam") << u"<html><body><a href=\"http://www.google.fr/url?q=http://www.yahoo.com\">test</a></body></html>"_s << true;
     QTest::newRow("Redirect no scam") << QStringLiteral(
         "<html><body><a href=\"kmail:showAuditLog?log=http://www.foo.com%3http://www.bla.com\">test</a></body></html>")
                                       << false;
@@ -74,10 +75,10 @@ void ScamDetectionWebEngineTest::scamtest_data()
     QTest::newRow("numeric no scam") << QStringLiteral(
         "<html><body><a href=\"http://baseball2.2ndhalfplays.com/nested/attribs/\">http://baseball2.2ndhalfplays.com/nested/attribs</html>")
                                      << false;
-    QTest::newRow("numeric scam1") << QStringLiteral("<html><body><a href=\"http://25.15.55.88/\">test</a></body></html>") << true;
-    QTest::newRow("numeric scam2") << QStringLiteral("<html><body><a href=\"http://255.0.1.1/\">test</a></body></html>") << true;
-    QTest::newRow("numeric scam3") << QStringLiteral("<html><body><a href=\"http://1.0.1.1/\">test</a></body></html>") << true;
-    QTest::newRow("numeric scam4") << QStringLiteral("<html><body><a href=\"http://255.500.1.1/\">test</a></body></html>") << true;
+    QTest::newRow("numeric scam1") << u"<html><body><a href=\"http://25.15.55.88/\">test</a></body></html>"_s << true;
+    QTest::newRow("numeric scam2") << u"<html><body><a href=\"http://255.0.1.1/\">test</a></body></html>"_s << true;
+    QTest::newRow("numeric scam3") << u"<html><body><a href=\"http://1.0.1.1/\">test</a></body></html>"_s << true;
+    QTest::newRow("numeric scam4") << u"<html><body><a href=\"http://255.500.1.1/\">test</a></body></html>"_s << true;
     QTest::newRow("numeric scam5") << QStringLiteral(
         "<html><body><a href=\"http://baseball.2ndhalfplays.com/nested/attribs/\">http://baseball2.2ndhalfplays.com/nested/attribs</html>")
                                    << true;
@@ -96,8 +97,8 @@ void ScamDetectionWebEngineTest::scamtest_data()
         "<a href=\"https://github.com/KDAB/KDStateMachineEditor.git|1.2\">https://github.com/KDAB/KDStateMachineEditor.git|1.2</a>")
                                        << false;
 
-    QTest::newRow("scam-lowercase") << QStringLiteral("<a href=\"http://www.Kde.org\">http://www.Kde.org</a>") << false;
-    QTest::newRow("scam-lowercase-2") << QStringLiteral("<a href=\"http://www.Kde.org/KDE/bla\">http://www.Kde.org/KDE/bla</a>") << false;
+    QTest::newRow("scam-lowercase") << u"<a href=\"http://www.Kde.org\">http://www.Kde.org</a>"_s << false;
+    QTest::newRow("scam-lowercase-2") << u"<a href=\"http://www.Kde.org/KDE/bla\">http://www.Kde.org/KDE/bla</a>"_s << false;
     QTest::newRow("scam-lowercase-3") << QStringLiteral(
         "<a href=\"http://code.qt.io/cgit/%7bnon-gerrit%7d/qt-labs/opencl.git\">http://code.qt.io/cgit/%7bnon-gerrit%7d/qt-labs/opencl.git</a>")
                                       << false;
@@ -122,14 +123,14 @@ void ScamDetectionWebEngineTest::scamtest_data()
         "<a "
         "href=\"http://g-ecx.images-amazon.com/images/G/01/barcodes/blank003.jpg%5CnUse\">http://g-ecx.images-amazon.com/images/G/01/barcodes/blank003.jpg/"
         "nUse</a>") << false;
-    QTest::newRow("wierd1") << QStringLiteral("<a href=\"http://www.weezevent.com?c=sys_mail\">http://www.weezevent.com?c=sys_mail</a>") << false;
+    QTest::newRow("wierd1") << u"<a href=\"http://www.weezevent.com?c=sys_mail\">http://www.weezevent.com?c=sys_mail</a>"_s << false;
 
-    QTest::newRow("urlwithport-special443") << QStringLiteral("<a href=\"https://example.com:443/blablabla\">https://example.com:443/blablabla</a>") << false;
-    QTest::newRow("urlwithport-special443-2") << QStringLiteral("<a href=\"http://example.com:443/blablabla\">http://example.com:443/blablabla</a>") << false;
-    QTest::newRow("urlwithport") << QStringLiteral("<a href=\"https://example.com:465/blablabla\">https://example.com:465/blablabla</a>") << false;
-    QTest::newRow("urlwithport2") << QStringLiteral("<a href=\"https://example.com:11371/blablabla\">https://example.com:11371/blablabla</a>") << false;
-    QTest::newRow("urlwithport3") << QStringLiteral("<a href=\"smtps://example.com:465/blablabla\">smtps://example.com:465/blablabla</a>") << false;
-    QTest::newRow("urlwithport3") << QStringLiteral("<a href=\"imaps://example.com:993/blablabla\">imaps://example.com:993/blablabla</a>") << false;
+    QTest::newRow("urlwithport-special443") << u"<a href=\"https://example.com:443/blablabla\">https://example.com:443/blablabla</a>"_s << false;
+    QTest::newRow("urlwithport-special443-2") << u"<a href=\"http://example.com:443/blablabla\">http://example.com:443/blablabla</a>"_s << false;
+    QTest::newRow("urlwithport") << u"<a href=\"https://example.com:465/blablabla\">https://example.com:465/blablabla</a>"_s << false;
+    QTest::newRow("urlwithport2") << u"<a href=\"https://example.com:11371/blablabla\">https://example.com:11371/blablabla</a>"_s << false;
+    QTest::newRow("urlwithport3") << u"<a href=\"smtps://example.com:465/blablabla\">smtps://example.com:465/blablabla</a>"_s << false;
+    QTest::newRow("urlwithport3") << u"<a href=\"imaps://example.com:993/blablabla\">imaps://example.com:993/blablabla</a>"_s << false;
     // Bug:440635
     QTest::newRow("scam5C") << QStringLiteral(R"(<a href="https://www.google.com/search?q=%5C">https://www.google.com/search?q=%5C</a>)") << false;
     QTest::newRow("BUG440635") << QStringLiteral(
