@@ -5,6 +5,7 @@
 */
 
 #include "testmaildndattachment.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include <KActionCollection>
 #include <KMime/Content>
@@ -22,15 +23,15 @@ TestMailDndAttachment::TestMailDndAttachment(QWidget *parent)
     auto vbox = new QVBoxLayout(this);
     auto viewer = new MessageViewer::Viewer(nullptr, nullptr, new KActionCollection(this));
     vbox->addWidget(viewer);
-    viewer->setMessage(readAndParseMail(QStringLiteral("encapsulated-with-attachment.mbox")) /*KMime::Message::Ptr(msg)*/);
-    viewer->setPluginName(QStringLiteral("longheaderstyleplugin"));
+    viewer->setMessage(readAndParseMail(u"encapsulated-with-attachment.mbox"_s) /*KMime::Message::Ptr(msg)*/);
+    viewer->setPluginName(u"longheaderstyleplugin"_s);
 }
 
 TestMailDndAttachment::~TestMailDndAttachment() = default;
 
 KMime::Message::Ptr TestMailDndAttachment::readAndParseMail(const QString &mailFile)
 {
-    QFile file(QLatin1StringView(MAIL_DATA_DIR) + QLatin1Char('/') + mailFile);
+    QFile file(QLatin1StringView(MAIL_DATA_DIR) + u'/' + mailFile);
     file.open(QIODevice::ReadOnly);
     QByteArray ba = file.readAll();
     qDebug() << ba;
