@@ -4,8 +4,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MIMETREEPARSER_TESTS_PROTECTEDHEADERSTEST_H
-#define MIMETREEPARSER_TESTS_PROTECTEDHEADERSTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -30,5 +29,3 @@ private Q_SLOTS:
     void testMessagePartsOfMailHeader_data();
     void testMessagePartsOfMailHeader();
 };
-
-#endif // MIMETREEPARSER_TESTS_PROTECTEDHEADERSTEST_H
