@@ -10,7 +10,7 @@ using namespace MimeTreeParser;
 
 MimeMessagePart::Ptr MimeTreeParser::createAndParseTempNode(Interface::BodyPart &part, KMime::Content *parentNode, const char *content, const char *cntDesc)
 {
-    auto *newNode = new KMime::Content();
+    auto newNode = new KMime::Content();
     newNode->setContent(KMime::CRLFtoLF(content));
     newNode->parse();
 
@@ -28,9 +28,9 @@ KMime::Content *MimeTreeParser::findTypeInDirectChilds(KMime::Content *content,
         return content;
     }
 
-    foreach (const auto child, content->contents()) {
-        if ((!child->contentType()->isEmpty())
-            && (mimeType == child->contentType(false)->mimeType())) {
+    const auto contents = content->contents();
+    for (const auto child : contents) {
+        if ((!child->contentType()->isEmpty()) && (mimeType == child->contentType(false)->mimeType())) {
             return child;
         }
     }
@@ -39,7 +39,8 @@ KMime::Content *MimeTreeParser::findTypeInDirectChilds(KMime::Content *content,
 
 MessagePart::Ptr MimeTreeParser::toplevelTextNode(MessagePart::Ptr messageTree)
 {
-    foreach (const auto &mp, messageTree->subParts()) {
+    const auto subParts = messageTree->subParts();
+    for (const auto &mp : subParts) {
         auto text = mp.dynamicCast<TextMessagePart>();
         auto attach = mp.dynamicCast<AttachmentMessagePart>();
         if (text && !attach) {
@@ -53,5 +54,5 @@ MessagePart::Ptr MimeTreeParser::toplevelTextNode(MessagePart::Ptr messageTree)
             }
         }
     }
-    return MessagePart::Ptr();
+    return {};
 }
