@@ -18,9 +18,9 @@ namespace MimeTreeParser
      found in 'cntDesc'.
   2. Parse the 'node' to display the content.
 */
-Q_REQUIRED_RESULT MimeMessagePart::Ptr createAndParseTempNode(Interface::BodyPart &part, KMime::Content *parentNode, const char *content, const char *cntDesc);
+[[nodiscard]] MimeMessagePart::Ptr createAndParseTempNode(Interface::BodyPart &part, KMime::Content *parentNode, const char *content, const char *cntDesc);
 
-Q_REQUIRED_RESULT KMime::Content *findTypeInDirectChilds(KMime::Content *content, const QByteArray &mimeType);
+[[nodiscard]] KMime::Content *findTypeInDirectChilds(KMime::Content *content, const QByteArray &mimeType);
 
-Q_REQUIRED_RESULT MessagePart::Ptr toplevelTextNode(MessagePart::Ptr messageTree);
+[[nodiscard]] MessagePart::Ptr toplevelTextNode(MessagePart::Ptr messageTree);
 }
